#!/bin/bash

MODULE_LIST=""

function getTestableModules {
  # OPEN_MODULES, PARTNER_MODULES
  echo $1
  readonly regEx='(((partner)(\-(.)+)*))'
  readonly moduleFile=modules.properties
  extractModules=""
  if [[ $1 == "PARTNER_MODULES" ]]; then
    extractModules=$(grep -E -i "$regEx" "$moduleFile" | cut -d '=' -f2 | cut -d '\' -f1 | cut -d ',' -f1)
  else
    extractModules=$(grep -v -E -i "$regEx" "$moduleFile" | cut -d '=' -f2 | cut -d '\' -f1 | cut -d ',' -f1)
  fi

  extractTestableModules "$extractModules"
}

function extractTestableModules {
  # exclude all, sample modules
  extractModules=$1
  readonly sampleRex='(#[A-Za-z\s]+|[A-Za-z]+\-)*(sample(\-(.)+)*)'
  readonly allRex='([a-zA-Z]*-)*(all)(\-(.)+)*'

  modulesExcludeSample=$(echo "$extractModules" | grep -v -E -i "$sampleRex")
  modulesExcludeSampleAndAll=$(echo "$modulesExcludeSample"| grep -v -E -i "$allRex")

  MODULE_LIST=$modulesExcludeSampleAndAll
}

function testModules {
  for module in $MODULE_LIST; do
    ./gradlew "$module:test" --console=plain
    resultCode=$?
    if [[ $resultCode != 0 ]]; then
      sendMsgToKakaoWork "$module"
      exit $resultCode
    fi
  done
}

function sendMsgToKakaoWork {
  errorModuleName=$1
  echo "Error Module: $errorModuleName"
  curl -X POST -H 'Content-Type: application/json' -d '{ "to": 20211, "msg": "[Android SDK] '$errorModuleName' Test failed" }' http://api.noti.daumkakao.io/send/messenger/group/kakaowork
}

# update test data
./gradlew updateTestData --console=plain

# test modules(open)
getTestableModules "OPEN_MODULES"
testModules

# test modules (partner)
getTestableModules "PARTNER_MODULES"
testModules
